@@ -7,6 +7,8 @@
 #define BOOKMARKSHISTORYMODEL_H
 
 #include <QAbstractListModel>
+#include <QtQml/qqmlregistration.h>
+
 
 struct BookmarksHistoryRecord {
     using ColumnTypes = std::tuple<int, QString, QString, QString, int>;
@@ -39,6 +41,8 @@ class BookmarksHistoryModel : public QAbstractListModel
     // bookmarks are shown
     Q_PROPERTY(QString filter READ filter WRITE setFilter NOTIFY filterChanged)
 
+    QML_ELEMENT
+
     enum Role {
         Id = Qt::UserRole + 1,
         Url,
