@@ -9,6 +9,7 @@
 
 #include <QAbstractListModel>
 #include <QUrl>
+#include <QtQml/qqmlregistration.h>
 
 class QJsonObject;
 
@@ -46,6 +47,8 @@ class TabsModel : public QAbstractListModel
     Q_PROPERTY(bool isMobileDefault READ isMobileDefault WRITE setIsMobileDefault NOTIFY isMobileDefaultChanged)
     Q_PROPERTY(bool privateMode READ privateMode WRITE setPrivateMode NOTIFY privateModeChanged REQUIRED)
 
+    QML_ELEMENT
+
     enum RoleNames { UrlRole = Qt::UserRole + 1, IsMobileRole, IsDeveloperToolsOpen };
 
 public:
@@ -68,6 +71,7 @@ public:
     Q_INVOKABLE void createEmptyTab();
     Q_INVOKABLE void setLatestTab();
     Q_INVOKABLE void closeTab(int index);
+    Q_INVOKABLE void reopenTab();
 
     Q_INVOKABLE void setUrl(int index, const QUrl &url);
     Q_INVOKABLE void setIsMobile(int index, bool isMobile);
@@ -87,6 +91,7 @@ protected:
 private:
     int m_currentTab = 0;
     std::vector<TabState> m_tabs{};
+    std::list<TabState> m_closedTabs{};
     bool m_privateMode = false;
     bool m_tabsReadOnly = false;
     bool m_isMobileDefault = false;
